yaegilab

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: BSD-3-Clause Imports: 8 Imported by: 1

Documentation

Overview

Package yaegilab provides functions connecting https://github.com/cogentcore/yaegi to Cogent Lab.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Interpreter

type Interpreter struct {
	*interpreter.Interpreter
}

Interpreter implements yaegicore.Interpreter using the interpreter.Interpreter for Goal.

func NewInterpreter

func NewInterpreter(options interp.Options) *Interpreter

NewInterpreter returns a new Interpreter initialized with the given options.

func (*Interpreter) Eval

func (in *Interpreter) Eval(src string) (res reflect.Value, err error)

func (*Interpreter) ImportUsed

func (in *Interpreter) ImportUsed()

func (*Interpreter) Use

func (in *Interpreter) Use(values interp.Exports) error

Directories

Path Synopsis
Package labsymbols contains yaegi symbols for lab GUI packages.
Package labsymbols contains yaegi symbols for lab GUI packages.
Package tensorsymbols contains yaegi symbols for tensor packages and other base lab packages.
Package tensorsymbols contains yaegi symbols for tensor packages and other base lab packages.

Jump to