Documentation
¶
Overview ¶
Package yaegilab provides functions connecting https://github.com/cogentcore/yaegi to Cogent Lab.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Interpreter ¶
type Interpreter struct {
*interpreter.Interpreter
}
Interpreter implements yaegicore.Interpreter using the interpreter.Interpreter for Goal.
func NewInterpreter ¶
func NewInterpreter(options interp.Options) *Interpreter
NewInterpreter returns a new Interpreter initialized with the given options.
func (*Interpreter) ImportUsed ¶
func (in *Interpreter) ImportUsed()
Directories
¶
| Path | Synopsis |
|---|---|
|
Package labsymbols contains yaegi symbols for lab GUI packages.
|
Package labsymbols contains yaegi symbols for lab GUI packages. |
|
Package tensorsymbols contains yaegi symbols for tensor packages and other base lab packages.
|
Package tensorsymbols contains yaegi symbols for tensor packages and other base lab packages. |
Click to show internal directories.
Click to hide internal directories.